slepc-3.18.0 2022-10-01
Report Typos and Errors

# DSGNHEP

Dense Generalized Non-Hermitian Eigenvalue Problem.

### Notes

The problem is expressed as A*X = B*X*Lambda, where (A,B) is the input matrix pencil. Lambda is a diagonal matrix whose diagonal elements are the arguments of DSSolve(). After solve, (A,B) is overwritten with the generalized (real) Schur form (S,T) = (Z'*A*Q,Z'*B*Q), with the first matrix being upper quasi-triangular and the second one triangular.

### Used DS matrices

| DS_MAT_A | - first problem matrix
| DS_MAT_B | - second problem matrix
| DS_MAT_Q | - first orthogonal/unitary transformation that reduces to generalized (real) Schur form
| DS_MAT_Z | - second orthogonal/unitary transformation that reduces to generalized (real) Schur form

### Implemented methods

| 0 | - QZ iteration (_gges)

### See Also

DSCreate(), DSSetType(), DSType

### Level

beginner

### Location

src/sys/classes/ds/impls/gnhep/dsgnhep.c
Index of all DS routines
Table of Contents for all manual pages
Index of all manual pages